<?php

/**
 * Photo Spot
 *
 * @package com_photospot_j15
 * @version 1-20100914.0
 */


class PhotoSpotDatasourceContentArticlesDisplay extends PhotoSpotDatasourceDisplay {
	var $intro_item = null;
	var $intro_text_before = '';
	var $intro_text_after = '';

	var $main_item = null;
	var $main_text_before = '';
	var $main_text_after = '';

	function get_url_basename($input) {
		$i = strpos($input, '?');
		if ($i > -1)
			$input = substr($input, 0, $i);
			
		return basename($input);
	}

	function analyze($src, $is_intro) {
		if (preg_match('~<\s*img.*?>~is', $src, $m)) {
			preg_match_all('~(\w*)\s*=\s*"([^"]*)"~s', $m[0], $m2);

			$attrs = array();
			for ($i = 0, $len = count($m2[0]); $i < $len; $i++)
				$attrs[strtolower($m2[1][$i])] = trim($m2[2][$i]);

			if (isset($attrs['src'])) {
				$item = new PhotoSpotDisplayItem();

				$item->link = $this->current_link;

				$item->img_url = $attrs['src'];

				$item->ext = strrchr($this->get_url_basename($item->img_url), '.');
				if (!empty($item->ext))
					$item->ext = strtolower(substr($item->ext, 1));

				if (!empty($attrs['title']))
					$item->title = $attrs['title'];
					
				if (empty($item->title) && !empty($attrs['alt']))
					$item->title = $attrs['alt'];

				if (isset($attrs['width']))
					$item->img_width = $attrs['width'];

				if (isset($attrs['height']))
					$item->img_height = $attrs['height'];
				
				$i = strpos($src, $m[0]);
				if ($is_intro) {
					$this->intro_item = $item;
					$this->intro_text_before = substr($src, 0, $i);
					$this->intro_text_after = substr($src, $i + strlen($m[0]));
				}
				else {
					$this->main_item = $item;
					$this->main_text_before = substr($src, 0, $i);
					$this->main_text_after = substr($src, $i + strlen($m[0]));
				}
			}
		}
	}

	function init($viewer) {
		require_once(JPATH_SITE . '/components/com_content/helpers/route.php');

		$db =& JFactory::getDBO();

		$user =& JFactory::getUser();
		$aid = (int) $user->get('aid', 0);

		$contentConfig =& JComponentHelper::getParams('com_content');
		$noauth = !$contentConfig->get('show_noauth');
		$date =& JFactory::getDate();
		$now = $date->toMySQL();

		$nullDate = $db->getNullDate();

		preg_match_all('/[0-9]+/', $this->params->get('articles', ''), $article_ids);
		preg_match_all('/[0-9]+/', $this->params->get('categories', ''), $cat_ids);
		preg_match_all('/[0-9]+/', $this->params->get('sections', ''), $sec_ids);

		$query_base =
'FROM #__content AS a
LEFT OUTER JOIN #__categories AS cc ON cc.id = a.catid
LEFT OUTER JOIN #__sections AS s ON s.id = a.sectionid
WHERE a.state = 1
' . (empty($article_ids[0]) ? '' : 'AND a.id IN (' . implode(',', $article_ids[0]) . ')') . '
' . (empty($cat_ids[0]) ? '' : 'AND a.catid IN (' . implode(',', $cat_ids[0]) . ')') . '
' . (empty($sec_ids[0]) ? '' : 'AND a.sectionid IN (' . implode(',', $sec_ids[0]) . ')') . '
' . ($noauth ? 'AND a.access <= ' . $aid. ' AND (a.catid = 0 OR (a.catid > 0 AND cc.access <= ' . $aid . ' AND s.access <= ' . $aid . '))' : '') . '
AND (a.publish_up = ' . $db->Quote($nullDate) . ' OR a.publish_up <= ' . $db->Quote($now) . ')
AND (a.publish_down = ' . $db->Quote($nullDate) . ' OR a.publish_down >= ' . $db->Quote($now) . ')
AND (a.catid = 0 OR (a.catid > 0 AND cc.published = 1 AND cc.section = s.id AND s.published = 1))';

		$db->setQuery('SELECT COUNT(a.id) ' . $query_base);
		$this->items_count = (int) $db->loadResult();

		$order_methods = array(
			'default' => 'a.ordering',
			'default_desc' => 'a.ordering DESC',
			'title' => 'a.title',
			'title_asc' => 'a.title',
			'title_desc' => 'a.title DESC',
			'cdate_asc' => 'a.created',
			'cdate_desc' => 'a.created DESC',
			'mdate_asc' => 'a.modified',
			'mdate_desc' => 'a.modified DESC',
			'random' => 'RAND()',
		);
		$order = $this->params->get('order', '');

		$query =
'SELECT a.*,
CASE WHEN CHAR_LENGTH(a.alias) THEN CONCAT_WS(":", a.id, a.alias) ELSE a.id END as slug,
CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(":", cc.id, cc.alias) ELSE cc.id END as catslug
' . $query_base . '
ORDER BY ' . (isset($order_methods[$order]) ? $order_methods[$order] : $order_methods['default']);

		$db->setQuery($query, $viewer->limitstart, $viewer->limit);
		$records = $db->loadObjectList();

		if (is_array($records)) {
			$select_imgsrc_order = explode('_', $this->params->get('select_imgsrc_order', 'artintro_artmain'));
			$search_thumbs = (bool) $this->params->get('search_thumbs', '');
			$select_title_order = explode('_', $this->params->get('select_title_order', 'arttitle'));
			$select_descr_order = explode('_', $this->params->get('select_descr_order', 'artintro_artmain'));
			$select_descr_text = $this->params->get('select_descr_text', 'before_after');
			$descr_length_limit = (int) $this->params->get('descr_length_limit', '0');

			foreach ($records as $rec) {
				$this->current_link = JRoute::_(ContentHelperRoute::getArticleRoute($rec->slug, $rec->catslug, $rec->sectionid));

				$this->intro_item = null;
				$this->intro_text_before = '';
				$this->intro_text_after = '';

				$this->main_item = null;
				$this->main_text_before = '';
				$this->main_text_after = '';

				$this->analyze($rec->introtext, true);
				$this->analyze($rec->fulltext, false);


				// select image
				
				$item = null;
				$image_source = 0;

				foreach ($select_imgsrc_order as $e) {
					if ($e == 'artintro' && $this->intro_item !== null) {
						$item = $this->intro_item;
						$image_source = 1;
						break;
					}
					else if ($e == 'artmain' && $this->main_item !== null) {
						$item = $this->main_item;
						$image_source = 2;
						break;
					}
				}

				if ($item === null) {
					$item = new PhotoSpotDisplayItem();
				}
				else if (
					$search_thumbs
					&& $item->img_url != ''
					&& strpos($item->img_url, '?') === false
					&& !preg_match('~^https?://~i', $item->img_url)
					&& preg_match('/(.+)\.([^.]+)\.([^.]+)$/', basename($item->img_url), $m)
					&& ($m[2] == 'small' || $m[2] == 'large')
				) {
					$path = preg_replace('~^/+~', '', str_replace('\\', '/', dirname($item->img_url)));					
					if ($path != '' && substr($path, -1) != '/')
						$path .= '/';
						
					$small = $path . $m[1] . '.small.' . $m[3];
					$large = $path . $m[1] . '.large.' . $m[3];

					if (file_exists(JPATH_SITE . '/' . $small) && file_exists(JPATH_SITE . '/' . $large)) {
						$item->thumb_abs = JPATH_SITE . '/' . $small;
						$info = getimagesize($item->thumb_abs);
						$item->thumb_url = $small;
						$item->thumb_width = $info[0];
						$item->thumb_height = $info[1];

						$item->img_abs = JPATH_SITE . '/' . $large;
						$info = getimagesize($item->img_abs);
						$item->img_url = $large;
						$item->img_width = $info[0];
						$item->img_height = $info[1];
						$item->mime = @$info['mime'];
						$item->ext = strtolower($m[3]);
						$item->mtime = filemtime($item->img_abs);
					}
				}


				// select description

				$descr = '';
				foreach ($select_descr_order as $e) {
					if ($e == 'artintro') {
						if ($image_source == 1) {
							if ($select_descr_text == 'before')
								$descr = $this->intro_text_before;
							else if ($select_descr_text == 'after')
								$descr = $this->intro_text_after;
							else
								$descr = $this->intro_text_before . ' ' . $this->intro_text_after;
						}
						else {
							$descr = $rec->introtext;
						}
						break;
					}
					else if ($e == 'artmain') {
						if ($image_source == 2) {
							if ($select_descr_text == 'before')
								$descr = $this->main_text_before;
							else if ($select_descr_text == 'after')
								$descr = $this->main_text_after;
							else
								$descr = $this->main_text_before . ' ' . $this->main_text_after;
						}
						else {
							$descr = $rec->fulltext;
						}
						break;
					}
					else if ($e == 'imgtitle' && !empty($item->title)) {
						$descr = $item->title;
						break;
					}
					else if ($e == 'imgfilename' && !empty($item->img_url)) {
						$descr = $this->get_url_basename($item->img_url);
						break;
					}
				}

				if ($descr != '') {
					$descr = trim(preg_replace('/ +/', ' ', str_replace("\t", ' ', str_replace("\n", ' ', str_replace("\r\n", ' ', strip_tags($descr, '<a><strong><em><i><b><u><span>'))))));
					
					if ($descr_length_limit > 0 && strlen($descr) > $descr_length_limit) {
						if ($descr{$descr_length_limit - 1} != ' ' && $descr{$descr_length_limit} != ' ') {
							$descr = substr($descr, 0, $descr_length_limit);
							while ($descr != '' && substr($descr, -1) != ' ')
								$descr = substr($descr, 0, -1);

							if ($descr != '')
								$descr = substr($descr, 0, -1);
						}

						$descr = substr($descr, 0, $descr_length_limit);
						$descr .= ' ...';
					}
					
					$item->description = $descr;
				}
				

				// select title

				foreach ($select_title_order as $e) {
					if ($e == 'arttitle') {
						$item->title = $rec->title;
						break;
					}
					else if ($e == 'imgtitle' && !empty($item->title)) {
						// use the title already in place
						break;
					}
					else if ($e == 'imgfilename' && !empty($item->img_url)) {
						$item->title = $this->get_url_basename($item->img_url);
						break;
					}
				}


				// finalize

				$this->items[] = $item;
			}
		}

		return '';
	}

}

$engine = new PhotoSpotDatasourceContentArticlesDisplay();

?>