<?php

/**
 * Photo Spot
 *
 * @package com_photospot_j15
 * @version 1-20100914.0
 */


class PhotoSpotDatasourceContentStoryDisplay extends PhotoSpotDatasourceDisplay {

	function get_url_basename($input) {
		$i = strpos($input, '?');
		if ($i > -1)
			$input = substr($input, 0, $i);
			
		return basename($input);
	}

	function analyze_img($src) {
		preg_match_all('~(\w*)\s*=\s*"([^"]*)"~s', $src, $m2);

		$attrs = array();
		for ($i = 0, $len = count($m2[0]); $i < $len; $i++)
			$attrs[strtolower($m2[1][$i])] = trim($m2[2][$i]);

		$item = new PhotoSpotDisplayItem();

		$item->link = $this->current_link;

		$item->img_url = (string) @$attrs['src'];

		$item->ext = strrchr($this->get_url_basename($item->img_url), '.');
		if (!empty($item->ext))
			$item->ext = strtolower(substr($item->ext, 1));

		if (!empty($attrs['title']))
			$item->title = $attrs['title'];
			
		if (empty($item->title) && !empty($attrs['alt']))
			$item->title = $attrs['alt'];

		if (isset($attrs['width']))
			$item->img_width = $attrs['width'];

		if (isset($attrs['height']))
			$item->img_height = $attrs['height'];

		if (
			$this->search_thumbs
			&& $item->img_url != ''
			&& strpos($item->img_url, '?') === false
			&& !preg_match('~^https?://~i', $item->img_url)
			&& preg_match('/(.+)\.([^.]+)\.([^.]+)$/', basename($item->img_url), $m)
			&& ($m[2] == 'small' || $m[2] == 'large')
		) {
			$path = preg_replace('~^/+~', '', str_replace('\\', '/', dirname($item->img_url)));					
			if ($path != '' && substr($path, -1) != '/')
				$path .= '/';
				
			$small = $path . $m[1] . '.small.' . $m[3];
			$large = $path . $m[1] . '.large.' . $m[3];

			if (file_exists(JPATH_SITE . '/' . $small) && file_exists(JPATH_SITE . '/' . $large)) {
				$item->thumb_abs = JPATH_SITE . '/' . $small;
				$info = getimagesize($item->thumb_abs);
				$item->thumb_url = $small;
				$item->thumb_width = $info[0];
				$item->thumb_height = $info[1];

				$item->img_abs = JPATH_SITE . '/' . $large;
				$info = getimagesize($item->img_abs);
				$item->img_url = $large;
				$item->img_width = $info[0];
				$item->img_height = $info[1];
				$item->mime = @$info['mime'];
				$item->mtime = filemtime($item->img_abs);
			}
		}

		$this->items[] = $item;
		
		return $item;
	}

	function analyze_part($src) {
		if (preg_match('~<\s*img([^>]*)>~i', $src, $m)) {
			$item = $this->analyze_img($m[0]);
			$k = strpos($src, $m[0]);
			$item->description = trim(preg_replace('~\s*<\s*p\s*>\s*$~i', '', substr($src, 0, $k)) . ' ' . preg_replace('~^\s*<\s*/\s*p\s*>\s*~i', '', substr($src, $k + strlen($m[0]))));
		}
	}

	function init($viewer) {
		require_once(JPATH_SITE . '/components/com_content/helpers/route.php');

		$db =& JFactory::getDBO();

		$user =& JFactory::getUser();
		$aid = (int) $user->get('aid', 0);

		$contentConfig =& JComponentHelper::getParams('com_content');
		$noauth = !$contentConfig->get('show_noauth');
		$date =& JFactory::getDate();
		$now = $date->toMySQL();

		$nullDate = $db->getNullDate();

		$article_id = (int) $this->params->get('article_id', '');

		if ($article_id == 0)
			return '';

		$query =
'SELECT a.*,
CASE WHEN CHAR_LENGTH(a.alias) THEN CONCAT_WS(":", a.id, a.alias) ELSE a.id END as slug,
CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(":", cc.id, cc.alias) ELSE cc.id END as catslug
FROM #__content AS a
LEFT OUTER JOIN #__categories AS cc ON cc.id = a.catid
LEFT OUTER JOIN #__sections AS s ON s.id = a.sectionid
WHERE a.id = ' . $article_id . ' AND a.state = 1
' . ($noauth ? 'AND a.access <= ' . $aid . ' AND (a.catid = 0 OR (a.catid > 0 AND cc.access <= ' . $aid . ' AND s.access <= ' . $aid . '))' : '') . '
AND (a.publish_up = ' . $db->Quote($nullDate) . ' OR a.publish_up <= ' . $db->Quote($now) . ')
AND (a.publish_down = ' . $db->Quote($nullDate) . ' OR a.publish_down >= ' . $db->Quote($now) . ')
AND (a.catid = 0 OR (a.catid > 0 AND cc.published = 1 AND cc.section = s.id AND s.published = 1))';

		$db->setQuery($query);
		$rec = $db->loadObject();

		if ($rec !== null) {
			$this->current_link = JRoute::_(ContentHelperRoute::getArticleRoute($rec->slug, $rec->catslug, $rec->sectionid));

			switch ($this->params->get('read_src', '')) {
				case 'intro':
					$src = trim($rec->introtext);
					break;

				case 'main':
					$src = trim($rec->fulltext);
					break;

				case 'all':
				default:
					$src = trim($rec->introtext . ' ' . $rec->fulltext);
			}

			$this->search_thumbs = (bool) $this->params->get('search_thumbs', '');

			$analyse_images = true;
			switch ($this->params->get('split', '')) {
				case 'pagebreak':
					while ($src != '' && preg_match_all('~<\s*hr([^>]*)>~i', $src, $m)) {
						$foundit = false;
						for ($i = 0, $len = count($m[0]); $i < $len; $i++)
							if (preg_match('~class\s*=\s*"system-pagebreak"~i', $m[1][$i])) {
								$k = strpos($src, $m[0][$i]);
								$this->analyze_part(substr($src, 0, $k));
								$src = substr($src, $k + strlen($m[0][$i]));
								$foundit = true;
							}
		
						if (!$foundit) {
							$this->analyze_part($src);
							$src = '';
						}
					}

					if ($src != '')
						$this->analyze_part($src);

					break;

				case 'nosplit':
					$this->analyze_part($src);
					break;

				case 'image':
				default:
					$item = null;
					
					while ($src != '' && preg_match('~<\s*img([^>]*)>~i', $src, $m)) {
						$k = strpos($src, $m[0]);

						if ($item !== null)
							$item->description = preg_replace('~\s*<\s*p\s*>\s*$~i', '', substr($src, 0, $k));
						
						$src = preg_replace('~^\s*<\s*/\s*p\s*>\s*~i', '', substr($src, $k + strlen($m[0])));

						$item = $this->analyze_img($m[0]);
					}

					if ($src != '' && $item !== null);
						$item->description = $src;
			}

			$this->items_count = count($this->items);

			switch ($this->params->get('order', '')) {
				case 'default_desc':
					$this->items = array_reverse($this->items);
					break;

				case 'filename_asc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_filename_asc'));
					break;

				case 'filename_desc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_filename_desc'));
					break;

				case 'title_asc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_title_asc'));
					break;

				case 'title_desc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_title_desc'));
					break;

				case 'mdate_asc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_mdate_asc'));
					break;

				case 'mdate_desc':
					usort($this->items, array('PhotoSpotDatasourceContentStoryDisplay', 'sort_mdate_desc'));
					break;

				case 'random':
					$count = $viewer->limit;
					if ($count == 0 || $count > $this->items_count)
						$count = $this->items_count;

					$new_list = array();
					for ($i = 0; $i < $count; $i++)
						$new_list = array_merge($new_list, array_splice($this->items, mt_rand(0, count($this->items) - 1), 1));

					$this->items = $new_list;

					break;
			}
		}

		if ($order != 'random' && $viewer->limit > 0 && $this->items_count > $viewer->limit)
			$this->items = array_slice($this->items, $viewer->limitstart, $viewer->limit);

		return '';
	}

	function sort_filename_asc($a, $b) {
		$a = $this->get_url_basename($a->img_url);
		$b = $this->get_url_basename($b->img_url);

		if ($a == $b)
			return 0;
		else
			return $a < $b ? -1 : 1;
	}

	function sort_filename_desc($a, $b) {
		$a = $this->get_url_basename($a->img_url);
		$b = $this->get_url_basename($b->img_url);

		if ($a == $b)
			return 0;
		else
			return $a < $b ? 1 : -1;
	}

	function sort_title_asc($a, $b) {
		if ($a->title == $b->title) {
			$a = $this->get_url_basename($a->img_url);
			$b = $this->get_url_basename($b->img_url);
			
			if ($a == $b)
				return 0;
			else
				return $a < $b ? -1 : 1;
		}
		else {
			return $a->title < $b->title ? -1 : 1;
		}
	}

	function sort_title_desc($a, $b) {
		if ($a->title == $b->title) {
			$a = $this->get_url_basename($a->img_url);
			$b = $this->get_url_basename($b->img_url);
			
			if ($a == $b)
				return 0;
			else
				return $a < $b ? 1 : -1;
		}
		else {
			return $a->title < $b->title ? 1 : -1;
		}
	}

	function sort_mdate_asc($a, $b) {
		if ($a->mtime == $b->mtime)
			return 0;
		else
			return $a->mtime < $b->mtime ? -1 : 1;
	}

	function sort_mdate_desc($a, $b) {
		if ($a->mtime == $b->mtime)
			return 0;
		else
			return $a->mtime < $b->mtime ? 1 : -1;
	}

}

$engine = new PhotoSpotDatasourceContentStoryDisplay();

?>