<?php

/**
 * Photo Spot
 *
 * @package com_photospot_j15
 * @version 1-20100914.0
 */


// no direct access
defined('_JEXEC') or die('Restricted access');

class PhotoSpotEngineInfo {
	var $type = 0;
	var $directory = '';
	var $code_name = '';
	var $title = '';
	var $id = 0;
	var $info = false;

	var $TYPE_INTERNAL = 1;
	var $TYPE_PLUGIN = 2;
}

class PhotoSpotUtils {

	function &get_instance() {
		static $instance = null;

		if ($instance === null)
			$instance = new PhotoSpotUtils();

		return $instance;
	}

	function get_info($name, $type, $find_title = false) {
		if (empty($name))
			return false;

		$result = false;

		// look in the component internal directories
		if (!empty($name) && file_exists(dirname(__FILE__) . '/lib_' . $type . '/' . $name . '/')) {
			$result = new PhotoSpotEngineInfo();
			$result->type = $result->TYPE_INTERNAL;
			$result->directory = dirname(__FILE__) . '/lib_' . $type . '/' . $name . '/';
			$result->code_name = $name;

			if ($find_title)
				$xml_filename = dirname(__FILE__) . '/lib_' . $type . '/' . $name . '.xml';
		}

		// look for published plugins
		if ($result === false) {
			$db =& JFactory::getDBO();

			$user =& JFactory::getUser();
			$aid = isset($user) ? $user->get('aid', 0) : 0;

			$db->setQuery(
"SELECT id
FROM #__plugins
WHERE published >= 1 AND client_id = 0 AND access <= " . (int) $aid . "
AND folder = 'photospot_$type' AND element = " . $db->Quote($name) . "
ORDER BY ordering
LIMIT 1"
			);
			$rec = $db->loadObject();
			if ($rec !== null) {
				$result = new PhotoSpotEngineInfo();
				$result->type = $result->TYPE_PLUGIN;
				$result->directory = JPATH_SITE . '/plugins/photospot_' . $type . '/' . $name . '/';
				$result->code_name = $name;
				$result->id = $rec->id;

				if ($find_title)
					$xml_filename = JPATH_SITE . '/plugins/photospot_' . $type . '/' . $name . '.xml';
			}
		}

		if ($result !== false && $find_title) {
			$xml =& JFactory::getXMLParser('Simple');
			if ($xml->loadFile($xml_filename)) {
				$element =& $xml->document->name[0];
				$result->title = $element ? $element->data() : $code_name;
			}
		}

		return $result;
	}

	function get_datasource_info($name, $find_title = false) {
		return $this->get_info($name, 'datasources', $find_title);
	}

	function get_viewer_info($name, $find_title = false) {
		return $this->get_info($name, 'viewers', $find_title);
	}

	function &load_display($info) {
		if (!file_exists($info->directory . 'display.php'))
			return JText::sprintf('Display engine for %s not found', $info->name);

		require_once($info->directory . 'display.php');
		return $engine;
	}

	function get_list($type) {
		$result = array();

		// load internal items

		$path = dirname(__FILE__) . '/lib_' . $type . '/';
		if ($dp = opendir($path)) {
			while (false !== ($file = readdir($dp))) {
				if (strtolower(substr($file, -4)) != '.xml')
					continue;

				$code_name = substr($file, 0, -4);
				$sub_dir = $path . $code_name;
				if (!file_exists($sub_dir) || !is_dir($sub_dir))
					continue;

				if (isset($xml))
					unset($xml);

				$xml =& JFactory::getXMLParser('Simple');
				if ($xml->loadFile($path . $file)) {
					$element =& $xml->document->name[0];
					$title = $element ? $element->data() : $code_name;

					$item = new PhotoSpotEngineInfo();
					$item->type = $item->TYPE_INTERNAL;
					$item->directory = dirname(__FILE__) . '/lib_' . $type . '/' . $code_name . '/';
					$item->code_name = $code_name;
					$item->title = $title;
					$item->info = array();

					$element =& $xml->document->creationDate[0];
					$item->info['creationDate'] = $element ? $element->data() : '';

					$element =& $xml->document->author[0];
					$item->info['author'] = $element ? $element->data() : '';

					$element =& $xml->document->authorEmail[0];
					$item->info['authorEmail'] = $element ? $element->data() : '';

					$element =& $xml->document->authorUrl[0];
					$item->info['authorUrl'] = $element ? $element->data() : '';

					$element =& $xml->document->copyright[0];
					$item->info['copyright'] = $element ? $element->data() : '';

					$element =& $xml->document->license[0];
					$item->info['license'] = $element ? $element->data() : '';

					$element =& $xml->document->description[0];
					$item->info['description'] = $element ? $element->data() : '';

					$result[$title] = $item;
				}
				unset($xml);
			}
			closedir($dp);
		}
		else {
			JError::raiseWarning('Could not open directory lib_datasources', JText::_('Could not open directory lib_datasources'));
			return;
		}


		// load plugins

		$db =& JFactory::getDBO();

		$user =& JFactory::getUser();
		$aid = isset($user) ? $user->get('aid', 0) : 0;

		$db->setQuery(
"SELECT id, element
FROM #__plugins
WHERE published >= 1 AND client_id = 0 AND access <= " . (int) $aid . " AND folder = 'photospot_$type'"
		);
		foreach ($db->loadObjectList() as $rec) {
			$code_name = $rec->element;

			if (!file_exists(JPATH_SITE . '/plugins/photospot_' . $type . '/' . $code_name . '.xml')
				|| !file_exists(JPATH_SITE . '/plugins/photospot_' . $type . '/' . $code_name)
				|| !is_dir(JPATH_SITE . '/plugins/photospot_' . $type . '/' . $code_name)
			)
				continue;

			if (isset($xml))
				unset($xml);

			$xml =& JFactory::getXMLParser('Simple');
			if ($xml->loadFile(JPATH_SITE . '/plugins/photospot_' . $type . '/' . $code_name . '.xml')) {
				$element =& $xml->document->name[0];
				$title = $element ? $element->data() : $code_name;

				$item = new PhotoSpotEngineInfo();
				$item->id = $rec->id;
				$item->type = $item->TYPE_PLUGIN;
				$item->directory = JPATH_SITE . '/plugins/photospot_' . $type . '/' . $code_name . '/';
				$item->code_name = $code_name;
				$item->title = $title;
				$item->info = array();

				$element =& $xml->document->creationDate[0];
				$item->info['creationDate'] = $element ? $element->data() : '';

				$element =& $xml->document->author[0];
				$item->info['author'] = $element ? $element->data() : '';

				$element =& $xml->document->authorEmail[0];
				$item->info['authorEmail'] = $element ? $element->data() : '';

				$element =& $xml->document->authorUrl[0];
				$item->info['authorUrl'] = $element ? $element->data() : '';

				$element =& $xml->document->copyright[0];
				$item->info['copyright'] = $element ? $element->data() : '';

				$element =& $xml->document->license[0];
				$item->info['license'] = $element ? $element->data() : '';

				$element =& $xml->document->description[0];
				$item->info['description'] = $element ? $element->data() : '';

				$result[$title] = $item;
			}
			unset($xml);
		}


		ksort($result);
		return $result;
	}

	function get_datasource_list() {
		return $this->get_list('datasources');
	}

	function get_viewer_list() {
		return $this->get_list('viewers');
	}

	function get_html_body($filename) {
		$result = '';

		if ($fp = fopen($filename, 'r')) {
			$contents = fread($fp, filesize($filename));
			fclose($fp);

			preg_match('~<\s*body[^>]*>(.*)<\s*/\s*body\s*>~is', $contents, $m);
			$result = $m[1];
		}

		return $result;
	}

	function get_help_body($filename) {
		$conf =& JFactory::getConfig();
		$filename = str_replace('LOCALE', $conf->getValue('config.language'), $filename);

		return $this->get_html_body($filename);
	}

	function norm_file_paths($filename, $add_url_root, &$url, &$absolute) {
		$url = str_replace('\\', '/', $filename);

		if ($url{0} == '/')
			$url = substr($url, 1);

		$absolute = JPATH_SITE . '/' . $url;

		if (file_exists($absolute)) {
			if (is_dir($absolute)) {
				$result = 'directory';
				if (substr($absolute, -1) != '/') {
					$absolute .= '/';
					$url .= '/';
				}
			}
			else {
				$result = 'file';
			}

			if ($add_url_root)
				$url = JURI::root() . $url;
		}
		else {
			$result = 'notfound';
		}

		return $result;
	}

}

?>